pref ("startup.homepage_override_url","");
pref ("startup.homepage_welcome_url","");
pref ("app.support.baseURL", "http://gnuzilla.gnu.org/");

// URL user can browse to manually if for some reason all update installation
// attempts fail.
pref ("app.update.url.manual", "http://gnuzilla.gnu.org/");
// A default value for the "More information about this update" link
// supplied in the "An update is available" page of the update wizard. 
pref ("app.update.url.details", "http://gnuzilla.gnu.org/");

// Release notes URL
pref ("app.releaseNotesURL", "http://gnuzilla.gnu.org/");

// Search codes belong only in builds with official branding
pref ("browser.search.param.yahoo-fr", "");
pref ("browser.search.param.yahoo-fr-cjkt", "");
pref ("browser.search.param.yahoo-f-CN", "");

pref ("pfs.datasource.url", "http://gnuzilla.gnu.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%");


// Release notes URL
pref ("app.releaseNotesURL", "http://gnuzilla.gnu.org/");
pref ("browser.EULA.3.accepted", true);
pref ("app.update.enabled", false);

// Search codes belong only in builds with official branding
pref ("browser.search.param.yahoo-fr", "");
pref ("browser.search.param.yahoo-fr-cjkt", "");
pref ("browser.search.param.yahoo-f-CN", "");


// Misc
pref ("network.http.pipelining", true);
